#!/usr/bin/env python
'''
This package installs a prebuilt version of PyQt5 for Mac OS. It does not
compile anything because uses an already precompiled one.

The main tools used to build PyQt5 depend on the package version:

    - 5.4.2.x: installs PyQt 5.4.2 built with SIP 4.16.8 and Python 3.4.3

Remember that Qt5 has to be installed already in your system in order to be
able to use PyQt5. On MAC OS, you can install Qt5 using brew:

    brew install qt5

WINDOWS and LINUX are NOT SUPPORTED by this script yet, sorry.

Usage:
    pyqt5_macos_built.py [-h]

Options:
    -h --help           Shows this screen

'''
import os
import site
import re
from docopt import docopt
from collections import namedtuple


def shorten(path):
    return re.sub('^' + os.getcwd() + '/', '', path)

if __name__ == '__main__':
    arguments = docopt(__doc__)

    links = []
    Link = namedtuple('Link', 'src dest')

    # Executable files
    bin_path = os.environ.get('VIRTUAL_ENV', '/usr/local')
    site_path = site.getsitepackages()[0]

    bin_files = os.listdir(site.getsitepackages()[0] + '/PyQt5/bin/')
    for bin_file in bin_files:
        src = site_path + '/PyQt5/bin/' + bin_file
        dest = bin_path + '/bin/' + bin_file
        links.append(Link(src=src, dest=dest))

    # Libraries
    src = site_path + '/PyQt5/lib/sip.so'
    dest = site_path + '/sip.so'
    links.append(Link(src=src, dest=dest))

    # Create symbolic links
    print('Making links:')
    for src, dest in links:
        os.symlink(src, dest)
        file_name = src.split('/')[-1]
        print('{}: {} -> {}'.format(file_name, shorten(dest), shorten(src)))

    print('\nChecking installation...')
    from PyQt5.QtCore import QT_VERSION_STR
    print('PyQt {} installed successfully'.format(QT_VERSION_STR))
